#!/usr/bin/env python
# coding: utf-8

# Extract data from EUSILC microdata
# 
# Since the demographic statistics are not available for every age, population is devided into age groups like the following:
# 1. 0-3
# 2. 4-12
# 3. 13-17
# 4. 18-22
# 5. 23-24
# 6. 25-49
# 7. 50-64
# 8. 65+
# 
# For that porpuse the microdata age statiscis will be replaced with groups insted of actual ages.

# In[80]:


import pandas as pd
import numpy as np
from os.path import join as joinpath

data_path = joinpath("data", "amsterdam", "before_simulation")
household = "NL_2013h_EUSILC.csv"
personal = "NL_2013p_EUSILC.csv"
household_register = "NL_2013d_EUSILC.csv"
personal_register = "NL_2013r_EUSILC.csv"

#variables we need from files
d_var = ["DB030","DB090"]#hhid, federal state, hh weight
p_var = ["PB030","PL031"] #economic status
r_var = ["RB030","RB090","RB050","RB080"] #person's id, person's gender, weights, year of birth

#read data and merge 
h = pd.read_csv(joinpath(data_path, household))
p = pd.read_csv(joinpath(data_path, personal))[p_var]
d = pd.read_csv(joinpath(data_path, household_register))[d_var]
r = pd.read_csv(joinpath(data_path, personal_register))[r_var]
r["hhid"] = (np.floor(r["RB030"]/100)).astype(int)
r["RB080"] = 2022-r["RB080"]

r = r.merge(d, left_on = "hhid", right_on = "DB030")
# r.to_csv(joinpath(data_path, "microdata_NL.csv"))

# add grpup og age instead age
age = r["RB080"]
for i in range(0,4):
    age = age.replace(i,1)
for i in range(4,13):
    age = age.replace(i,2)
for i in range(13,18):
    age = age.replace(i,3)
for i in range(18,23):
    age = age.replace(i,4)
for i in range(23,25):
    age = age.replace(i,5)
for i in range(25,50):
    age = age.replace(i,6)
for i in range(50,65):
    age = age.replace(i,7)
for i in range(65,120):
    age = age.replace(i,8)
r["RB080"] = age

ind = r[["RB090","RB080"]]
ind = ind.rename(columns={"RB090":"gender","RB080":"age"})
ind["gender"] = ind["gender"].replace({2:"f",1:"m"})
ind.to_csv(joinpath(data_path, "ind.csv"), sep=",")


# Filter marginal data to fit the IPF algorithm

# In[138]:



cons = pd.read_csv(joinpath(data_path, "2021-22-gebieden-1-02.csv"))
cons = cons.dropna()
cons=cons.rename(columns={"0-3":"1","12-Mar":"2","13-17":"3","18-22":"4","23-24":"5","25-49":"6","50-64":"7","65+":"8"})


# In[139]:


districts_lvl1 = ["A Centrum","E West","F Nieuw-West", "K Zuid","M Oost","N Noord","T Zuidoost"]
for d in districts_lvl1:
    cons = cons[cons["gb/std"] !=d]
cons.columns = cons.columns.astype(str)
cons.to_csv(joinpath(data_path, "cons.csv"), sep=',',index=False)

